# -*- coding: utf-8 -*-
# flake8: noqa

from ._config import config  # noqa
from ._config import set_database_path  # noqa

__author__ = "K.-Michael Aye"
__email__ = "kmichael.aye@gmail.com"
__version__ = "0.8.0"
